==> deepeval-0.16.3.tar.gz: deepeval-0.16.3/deepeval/metrics/bias_classifier.py <==
"""Metric for bias classifier - using the same min score subtraction methodology as the toxic classifier 
Rationale for bias classifier is described here https://arxiv.org/pdf/2208.05777.pdf
1 - Not Biased
0 - Bias
"""

import warnings
from typing import Optional

from ..singleton import Singleton
from ..test_case import LLMTestCase
from .metric import Metric
from ..run_test import assert_test


class UnBiasedMetric(Metric, metaclass=Singleton):
    def __init__(
        self, model_name: str = "original", minimum_score: float = 0.5
    ):  # see paper for rationale https://arxiv.org/pdf/2208.05777.pdf
        self.model_name = model_name
        self.minimum_score = minimum_score

    def __call__(self, output, expected_output, query: Optional[str] = "-"):
        score = self.measure(output, expected_output)
        success = score >= self.minimum_score
        return score

    def measure(self, test_case: LLMTestCase):
        if test_case.output is None:
            raise ValueError("Required attributes for test_case cannot be None")

        from Dbias.bias_classification import classifier

        warnings.warn(
            "Run `pip install deepeval[bias]`. If you have, please ignore this warning."
        )

        results = classifier(test_case.output)
        # sample output
        # [{'label': 'Biased', 'score': 0.9938021898269653}]
        if results[0]["label"] == "Biased":
            v = 0.5 - (results[0]["score"] / 2)
        else:
            # if it's unbiased - use normal score
            v = 0.5 + (results[0]["score"] / 2)

        self.success = False
        if v > self.minimum_score:
            self.success = True

        self.score = v
        return v

    def is_successful(self):
        return self.success

    def assert_successful(self):
        assert self.success, f"Text is biased - score: {self.score}"

    @property
    def __name__(self):
        return "Bias Score"


def assert_unbiased(
    text: str, minimum_score: float = 0.5
):  # see paper for rationale https://arxiv.org/pdf/2208.05777.pdf
    metric = UnBiasedMetric(minimum_score=minimum_score)
    test_case = LLMTestCase(output=text)
    assert_test(test_case, [metric])

==> deepeval-0.20.1.tar.gz: deepeval-0.20.1/deepeval/metrics/bias_classifier.py <==
"""Metric for bias classifier - using the same min score subtraction methodology as the toxic classifier 
Rationale for bias classifier is described here https://arxiv.org/pdf/2208.05777.pdf
1 - Not Biased
0 - Bias
"""

import warnings
from typing import Optional
from .metric import Metric

from ..singleton import Singleton
from ..test_case import LLMTestCase
from ..run_test import assert_test


class UnBiasedMetric(Metric, metaclass=Singleton):
    def __init__(
        self, model_name: str = "original", minimum_score: float = 0.5
    ):  # see paper for rationale https://arxiv.org/pdf/2208.05777.pdf
        self.model_name = model_name
        self.minimum_score = minimum_score

    def __call__(self, output, expected_output, query: Optional[str] = "-"):
        score = self.measure(output, expected_output)
        success = score >= self.minimum_score
        return score

    def measure(self, test_case: LLMTestCase, return_all_scores: bool = False):
        if test_case.output is None:
            raise ValueError("Required attributes for test_case cannot be None")

        from Dbias.bias_classification import classifier

        warnings.warn(
            "Run `pip install deepeval[bias]`. If you have, please ignore this warning."
        )

        results = classifier(test_case.output)
        # sample output
        # [{'label': 'Biased', 'score': 0.9938021898269653}]
        if results[0]["label"] == "Biased":
            v = 0.5 - (results[0]["score"] / 2)
        else:
            # if it's unbiased - use normal score
            v = 0.5 + (results[0]["score"] / 2)

        self.success = False
        if v > self.minimum_score:
            self.success = True

        self.score = v
        if return_all_scores:
            return results
        return v

    def is_successful(self):
        return self.success

    def assert_successful(self):
        assert self.success, f"Text is biased - score: {self.score}"

    @property
    def __name__(self):
        return "Bias Score"


def assert_unbiased(
    text: str, minimum_score: float = 0.5
):  # see paper for rationale https://arxiv.org/pdf/2208.05777.pdf
    metric = UnBiasedMetric(minimum_score=minimum_score)
    test_case = LLMTestCase(output=text)
    assert_test(test_case, [metric])


def is_unbiased(
    text: str,
    minimum_score: float = 0.5,
) -> bool:
    """Check if the text is unbiased."""

    metric = UnBiasedMetric(minimum_score=minimum_score)
    test_case = LLMTestCase(output=text)
    return metric.measure(test_case) >= minimum_score
